#[non_exhaustive]pub enum FeatureStatus {
Embedder,
Unstable,
Internal,
Developer,
Testable,
Preview,
Stable,
Mature,
}v2_42 only.Expand description
Describes the status of a [structFeature].
The status for a given feature can be obtained with
[idFeature::status()].
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Embedder
Feature that adjust behaviour for specific application needs. The feature is not part of a Web platform feature, not a mature feature intended to be always on.
Unstable
Feature in development. The feature may be unfinished, and there are no guarantees about its safety and stability.
Internal
Feature for debugging the WebKit engine. The feature is not generally useful for user or web developers, and always disabled by default.
Developer
Feature for web developers. The feature is not generally useful for end users, and always disabled by default.
Testable
Feature in active development and complete enough for testing. The feature may not be yet ready to ship and is disabled by default.
Preview
Feature ready to be tested by users. The feature is disabled by default, but may be enabled by applications automatically e.g. in their “technology preview” or “beta” versions.
Stable
Feature ready for general use. The feature is enabled by default, but it may still be toggled to support debugging and testing.
Mature
Feature in general use. The feature is always enabled and in general there should be no user-facing interface to toggle it.