#[non_exhaustive]pub enum JavascriptError {
ScriptFailed,
InvalidParameter,
InvalidResult,
}Expand description
Enum values used to denote errors happening when executing JavaScript
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ScriptFailed
An exception was raised in JavaScript execution
InvalidParameter
An unsupported parameter has been used to call and async function from API. Since 2.40
InvalidResult
The result of JavaScript execution could not be returned. Since 2.40
Implementations