#[non_exhaustive]pub enum MediaError {
Load,
}Expand description
Enum values used to denote the various media errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Load
Preliminary load failure for media content types. A new load will be started to perform the media load. Since: 2.40
Implementations