#[non_exhaustive]pub enum SaveMode {
Mhtml,
}Expand description
Enum values to specify the different ways in which a #WebKitWebView can save its current web page into a self-contained file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Mhtml
Save the current page using the MHTML format.