#[non_exhaustive]pub enum UserScriptInjectionTime {
Start,
End,
}Expand description
Specifies at which place of documents an user script will be inserted.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Start
Insert the code of the user script at the beginning of loaded documents. This is the default.
End
Insert the code of the user script at the end of the loaded documents.