pub struct ApplicationInfo { /* private fields */ }Expand description
Information about an application running in automation mode.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl ApplicationInfo
impl ApplicationInfo
Sourcepub fn as_ptr(&self) -> *mut WebKitApplicationInfo
pub fn as_ptr(&self) -> *mut WebKitApplicationInfo
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitApplicationInfo) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitApplicationInfo) -> &Self
Borrows the underlying C value.
Sourceimpl ApplicationInfo
impl ApplicationInfo
Sourcepub fn new() -> ApplicationInfo
pub fn new() -> ApplicationInfo
Sourcepub fn name(&self) -> Option<GString>
pub fn name(&self) -> Option<GString>
Get the name of the application.
If set_name() hasn’t been
called with a valid name, this returns g_get_prgname().
Returns
the application name
Sourcepub fn version(&self) -> (u64, u64, u64)
pub fn version(&self) -> (u64, u64, u64)
Get the application version previously set with set_version().
Returns
major
return location for the major version number
minor
return location for the minor version number
micro
return location for the micro version number
Sourcepub fn set_version(&self, major: u64, minor: u64, micro: u64)
pub fn set_version(&self, major: u64, minor: u64, micro: u64)
Set the application version.
If the application doesn’t use the format major.minor.micro you can pass 0 as the micro to use major.minor, or pass 0 as both micro and minor to use only major number. Any other format must be converted to major.minor.micro so that it can be used in version comparisons.
major
the major version number
minor
the minor version number
micro
the micro version number