pub struct AutomationSession { /* private fields */ }Expand description
Automation Session.
WebKitAutomationSession represents an automation session of a WebKitWebContext.
When a new session is requested, a WebKitAutomationSession is created and the signal
WebKitWebContext::automation-started is emitted with the WebKitAutomationSession as
argument. Then, the automation client can request the session to create a new
WebView to interact with it. When this happens the signal create-web-view
is emitted.
Properties
id
The session unique identifier.
Readable | Writeable | Construct Only
Signals
create-web-view
This signal is emitted when the automation client requests a new
browsing context to interact with it. The callback handler should
return a WebView created with is-controlled-by-automation
construct property enabled and automation-presentation-type construct
property set if needed.
If the signal is emitted with “tab” detail, the returned WebView should be
a new web view added to a new tab of the current browsing context window.
If the signal is emitted with “window” detail, the returned WebView should be
a new web view added to a new window.
When creating a new web view and there’s an active browsing context, the new window
or tab shouldn’t be focused.
Detailed
will-close
This signal is emitted when the given automation session is about to finish. It allows clients to perform any cleanup tasks before the session is destroyed.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AutomationSession
impl AutomationSession
Sourcepub fn application_info(&self) -> Option<ApplicationInfo>
pub fn application_info(&self) -> Option<ApplicationInfo>
Get the the previously set AutomationSession.
Get the AutomationSession previously set with set_application_info().
Returns
the AutomationSession of self, or None if no one has been set.
Sourcepub fn set_application_info(&self, info: &ApplicationInfo)
pub fn set_application_info(&self, info: &ApplicationInfo)
Set the application information to self.
This information will be used by the driver service
to match the requested capabilities with the actual application information. If this information
is not provided to the session when a new automation session is requested, the creation might fail
if the client requested a specific browser name or version. This will not have any effect when called
after the automation session has been fully created, so this must be called in the callback of
automation-started signal.
info
Sourcepub fn connect_create_web_view<F: Fn(&Self) -> WebView + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
pub fn connect_create_web_view<F: Fn(&Self) -> WebView + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
This signal is emitted when the automation client requests a new
browsing context to interact with it. The callback handler should
return a WebView created with is-controlled-by-automation
construct property enabled and automation-presentation-type construct
property set if needed.
If the signal is emitted with “tab” detail, the returned WebView should be
a new web view added to a new tab of the current browsing context window.
If the signal is emitted with “window” detail, the returned WebView should be
a new web view added to a new window.
When creating a new web view and there’s an active browsing context, the new window
or tab shouldn’t be focused.
Returns
a WebView widget.
Sourcepub fn connect_will_close<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
Available on crate feature v2_46 only.
pub fn connect_will_close<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v2_46 only.This signal is emitted when the given automation session is about to finish. It allows clients to perform any cleanup tasks before the session is destroyed.