pub struct BackForwardList { /* private fields */ }Expand description
List of visited pages.
WebKitBackForwardList maintains a list of visited pages used to navigate to recent pages. Items are inserted in the list in the order they are visited.
WebKitBackForwardList also maintains the notion of the current item
(which is always at index 0), the preceding item (which is at index -1),
and the following item (which is at index 1).
Methods WebViewExt::go_back() and WebViewExt::go_forward() move
the current item backward or forward by one. Method
WebViewExt::go_to_back_forward_list_item() sets the current item to the
specified item. All other methods returning BackForwardListItems
do not change the value of the current item, they just return the requested
item or items.
Signals
changed
This signal is emitted when back_forward_list changes. This happens
when the current item is updated, a new item is added or one or more
items are removed. Note that both item_added and items_removed can
None when only the current item is updated. Items are only removed
when the list is cleared or the maximum items limit is reached.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl BackForwardList
impl BackForwardList
Sourcepub fn back_item(&self) -> Option<BackForwardListItem>
pub fn back_item(&self) -> Option<BackForwardListItem>
Returns the item that precedes the current item.
Returns
the BackForwardListItem
preceding the current item or None.
Sourcepub fn back_list(&self) -> Vec<BackForwardListItem>
pub fn back_list(&self) -> Vec<BackForwardListItem>
Obtain the list of items preceding the current one.
Returns
a GList of
items preceding the current item.
Sourcepub fn back_list_with_limit(&self, limit: u32) -> Vec<BackForwardListItem>
pub fn back_list_with_limit(&self, limit: u32) -> Vec<BackForwardListItem>
Sourcepub fn current_item(&self) -> Option<BackForwardListItem>
pub fn current_item(&self) -> Option<BackForwardListItem>
Sourcepub fn forward_item(&self) -> Option<BackForwardListItem>
pub fn forward_item(&self) -> Option<BackForwardListItem>
Returns the item that follows the current item.
Returns
the BackForwardListItem
following the current item or None.
Sourcepub fn forward_list(&self) -> Vec<BackForwardListItem>
pub fn forward_list(&self) -> Vec<BackForwardListItem>
Obtain the list of items following the current one.
Returns
a GList of
items following the current item.
Sourcepub fn forward_list_with_limit(&self, limit: u32) -> Vec<BackForwardListItem>
pub fn forward_list_with_limit(&self, limit: u32) -> Vec<BackForwardListItem>
Sourcepub fn nth_item(&self, index: i32) -> Option<BackForwardListItem>
pub fn nth_item(&self, index: i32) -> Option<BackForwardListItem>
Returns the item at a given index relative to the current item.
index
the index of the item
Returns
the BackForwardListItem
located at the specified index relative to the current item or None.