pub struct ContextMenu { /* private fields */ }Expand description
Represents the context menu in a WebView.
ContextMenu represents a context menu containing
ContextMenuItems in a WebView.
When a WebView is about to display the context menu, it
emits the context-menu signal, which has the
ContextMenu as an argument. You can modify it, adding new
submenus that you can create with new(), adding
new ContextMenuItems with
prepend(), append() or
insert(), maybe after having removed the
existing ones with remove_all().
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ContextMenu
impl ContextMenu
Sourcepub fn new() -> ContextMenu
pub fn new() -> ContextMenu
Creates a new ContextMenu object.
Creates a new ContextMenu object to be used as a submenu of an existing
ContextMenu. The context menu of a WebView is created by the view
and passed as an argument of context-menu signal.
To add items to the menu use prepend(),
append() or insert().
See also with_items() to create a ContextMenu with
a list of initial items.
Returns
The newly created ContextMenu object
Sourcepub fn with_items(items: &[ContextMenuItem]) -> ContextMenu
pub fn with_items(items: &[ContextMenuItem]) -> ContextMenu
Creates a new ContextMenu object with the given items.
Creates a new ContextMenu object to be used as a submenu of an existing
ContextMenu with the given initial items.
See also new()
items
a GList of ContextMenuItem
Returns
The newly created ContextMenu object
Sourcepub fn append(&self, item: &ContextMenuItem)
pub fn append(&self, item: &ContextMenuItem)
Sourcepub fn first(&self) -> Option<ContextMenuItem>
pub fn first(&self) -> Option<ContextMenuItem>
Gets the first item in the self.
Returns
the first ContextMenuItem of self,
or None if the ContextMenu is empty.
Sourcepub fn event(&self) -> Option<Event>
pub fn event(&self) -> Option<Event>
Gets the gdk::Event that triggered the context menu. This function only returns a valid
gdk::Event when called for a ContextMenu passed to context-menu
signal; in all other cases, None is returned.
The returned gdk::Event is expected to be one of the following types:
<itemizedlist>
<listitem>``<para>
a GdkEventButton of type GDK_BUTTON_PRESS when the context menu was triggered with mouse.
</para>``</listitem>
<listitem>``<para>
a GdkEventKey of type GDK_KEY_PRESS if the keyboard was used to show the menu.
</para>``</listitem>
<listitem>``<para>
a generic gdk::Event of type GDK_NOTHING when the popup-menu signal was used to show the context menu.
</para>``</listitem>
</itemizedlist>
Returns
the menu event or None.
Sourcepub fn item_at_position(&self, position: u32) -> Option<ContextMenuItem>
pub fn item_at_position(&self, position: u32) -> Option<ContextMenuItem>
Gets the item at the given position in the self.
position
the position of the item, counting from 0
Returns
the ContextMenuItem at position position in self,
or None if the position is off the end of the self.
Sourcepub fn items(&self) -> Vec<ContextMenuItem>
pub fn items(&self) -> Vec<ContextMenuItem>
Sourcepub fn position(&self) -> Option<(i32, i32)>
Available on crate feature v2_52 only.
pub fn position(&self) -> Option<(i32, i32)>
v2_52 only.Gets the position in view coordinates where the context menu was triggered.
This function only returns valid coordinates when called for a ContextMenu
passed to context-menu signal.
Returns
true if valid position coordinates are available, false otherwise
x
return location for the x coordinate
y
return location for the y coordinate
Sourcepub fn user_data(&self) -> Option<Variant>
pub fn user_data(&self) -> Option<Variant>
Gets the user data of self.
This function can be used from the UI Process to get user data previously set
from the Web Process with set_user_data().
Returns
the user data of self, or None if self doesn’t have user data
Sourcepub fn insert(&self, item: &ContextMenuItem, position: i32)
pub fn insert(&self, item: &ContextMenuItem, position: i32)
Inserts item into the self at the given position.
If position is negative, or is larger than the number of items
in the ContextMenu, the item is added on to the end of
the self. The first position is 0.
item
the ContextMenuItem to add
position
the position to insert the item
Sourcepub fn last(&self) -> Option<ContextMenuItem>
pub fn last(&self) -> Option<ContextMenuItem>
Gets the last item in the self.
Returns
the last ContextMenuItem of self,
or None if the ContextMenu is empty.
Sourcepub fn move_item(&self, item: &ContextMenuItem, position: i32)
pub fn move_item(&self, item: &ContextMenuItem, position: i32)
Moves item to the given position in the self.
If position is negative, or is larger than the number of items
in the ContextMenu, the item is added on to the end of
the self.
The first position is 0.
item
the ContextMenuItem to add
position
the new position to move the item
Sourcepub fn prepend(&self, item: &ContextMenuItem)
pub fn prepend(&self, item: &ContextMenuItem)
Sourcepub fn remove(&self, item: &ContextMenuItem)
pub fn remove(&self, item: &ContextMenuItem)
Removes item from the self.
See also remove_all() to remove all items.
item
the ContextMenuItem to remove
Sourcepub fn remove_all(&self)
pub fn remove_all(&self)
Removes all items of the self.
Sourcepub fn set_user_data(&self, user_data: &Variant)
pub fn set_user_data(&self, user_data: &Variant)
Sets user data to self.
This function can be used from a Web Process extension to set user data
that can be retrieved from the UI Process using user_data().
If the user_data glib::Variant is floating, it is consumed.