pub struct ContextMenuItem { /* private fields */ }Expand description
One item of a ContextMenu.
The ContextMenu is composed of ContextMenuItems. These items can be created from a GtkAction, from a
ContextMenuAction or from a ContextMenuAction and a
label. These ContextMenuActions denote stock actions
for the items. You can also create separators and submenus.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ContextMenuItem
impl ContextMenuItem
Sourcepub fn from_gaction(
action: &impl IsA<Action>,
label: &str,
target: Option<&Variant>,
) -> ContextMenuItem
pub fn from_gaction( action: &impl IsA<Action>, label: &str, target: Option<&Variant>, ) -> ContextMenuItem
Creates a new ContextMenuItem for the given action and label.
On activation
target will be passed as parameter to the callback.
action
label
the menu item label text
target
a glib::Variant to use as the action target
Returns
the newly created ContextMenuItem object.
Sourcepub fn from_stock_action(action: ContextMenuAction) -> ContextMenuItem
pub fn from_stock_action(action: ContextMenuAction) -> ContextMenuItem
Creates a new ContextMenuItem for the given stock action.
Stock actions are handled automatically by WebKit so that, for example,
when a menu item created with a ContextMenuAction::Stop is
activated the action associated will be handled by WebKit and the current
load operation will be stopped. You can get the gio::Action of a
ContextMenuItem created with a ContextMenuAction with
gaction() and connect to the GSimpleAction::activate signal
to be notified when the item is activated, but you can’t prevent the associated
action from being performed.
action
a ContextMenuAction stock action
Returns
the newly created ContextMenuItem object.
Sourcepub fn from_stock_action_with_label(
action: ContextMenuAction,
label: &str,
) -> ContextMenuItem
pub fn from_stock_action_with_label( action: ContextMenuAction, label: &str, ) -> ContextMenuItem
Creates a new ContextMenuItem for the given stock action using the given label.
Stock actions have a predefined label, this method can be used to create a
ContextMenuItem for a ContextMenuAction but using a custom label.
action
a ContextMenuAction stock action
label
a custom label text to use instead of the predefined one
Returns
the newly created ContextMenuItem object.
Sourcepub fn new_separator() -> ContextMenuItem
pub fn new_separator() -> ContextMenuItem
Creates a new ContextMenuItem representing a separator.
Returns
the newly created ContextMenuItem object.
Creates a new ContextMenuItem using the given label with a submenu.
label
the menu item label text
submenu
a ContextMenu to set
Returns
the newly created ContextMenuItem object.
Sourcepub fn gaction(&self) -> Option<Action>
pub fn gaction(&self) -> Option<Action>
Gets the action associated to self as a gio::Action.
Returns
the gio::Action associated to the ContextMenuItem,
or None if self is a separator.
Sourcepub fn gaction_target(&self) -> Option<Variant>
Available on crate feature v2_52 only.
pub fn gaction_target(&self) -> Option<Variant>
v2_52 only.Gets the target glib::Variant associated with self.
Returns
the target glib::Variant of the ContextMenuItem,
or None if self was not created with from_gaction()
or if no target was specified.
Sourcepub fn stock_action(&self) -> ContextMenuAction
pub fn stock_action(&self) -> ContextMenuAction
Gets the ContextMenuAction of self.
If the ContextMenuItem was not
created for a stock action ContextMenuAction::Custom will be
returned. If the ContextMenuItem is a separator ContextMenuAction::NoAction
will be returned.
Returns
the ContextMenuAction of self
Gets the submenu of self.
Returns
the ContextMenu representing the submenu of
self or None if self doesn’t have a submenu.
Sourcepub fn is_separator(&self) -> bool
pub fn is_separator(&self) -> bool