Credential

Struct Credential 

pub struct Credential { /* private fields */ }
Groups information used for user authentication.

GLib type: Boxed type with copy-on-clone semantics.

Implementations

Source

impl Credential

pub fn as_ptr(&self) -> *mut WebKitCredential

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitCredential) -> &Self

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut( ptr: &mut *mut WebKitCredential, ) -> &mut Self

Borrows the underlying C value mutably.

Source

impl Credential

pub fn new( username: &str, password: &str, persistence: CredentialPersistence, ) -> Credential

Create a new credential from the provided username, password and persistence mode.

username

The username for the new credential

password

The password for the new credential

persistence

The CredentialPersistence of the new credential

Returns

A Credential.

pub fn for_certificate( certificate: Option<&impl IsA<TlsCertificate>>, persistence: CredentialPersistence, ) -> Credential

Create a new credential from the certificate and persistence mode.

Note that CredentialPersistence::Permanent is not supported for certificate credentials.

certificate

The gio::TlsCertificate, or None

persistence

The CredentialPersistence of the new credential

Returns

A Credential.

pub fn for_certificate_pin( pin: &str, persistence: CredentialPersistence, ) -> Credential

Create a new credential from the provided PIN and persistence mode.

Note that CredentialPersistence::Permanent is not supported for certificate pin credentials.

pin

The PIN for the new credential

persistence

The CredentialPersistence of the new credential

Returns

A Credential.

pub fn certificate(&mut self) -> Option<TlsCertificate>

Get the certificate currently held by this Credential.

Returns

a gio::TlsCertificate, or None

pub fn password(&mut self) -> Option<GString>

Get the password currently held by this Credential.

Returns

The password stored in the Credential.

pub fn persistence(&mut self) -> CredentialPersistence

Get the persistence mode currently held by this Credential.

Returns

The CredentialPersistence stored in the Credential.

pub fn username(&mut self) -> Option<GString>

Get the username currently held by this Credential.

Returns

The username stored in the Credential.

pub fn has_password(&mut self) -> bool

Determine whether this credential has a password stored.

Returns

true if the credential has a password or false otherwise.