pub struct Download { /* private fields */ }Expand description
Object used to communicate with the application when downloading.
Download carries information about a download request and
response, including a URIRequest and a URIResponse
objects. The application may use this object to control the
download process, or to simply figure out what is to be downloaded,
and handle the download process itself.
Properties
allow-overwrite
Whether or not the download is allowed to overwrite an existing file on
disk. If this property is false and the destination already exists,
the download will fail.
Readable | Writeable
destination
The local path to where the download will be saved.
Readable
estimated-progress
An estimate of the percent completion for the download operation.
This value will range from 0.0 to 1.0. The value is an estimate
based on the total number of bytes expected to be received for
a download.
If you need a more accurate progress information you can connect to
received-data signal to track the progress.
Readable
response
The URIResponse associated with this download.
Readable
Signals
created-destination
This signal is emitted after decide-destination and before
received-data to notify that destination file has been
created successfully at destination.
decide-destination
This signal is emitted after response is received to
decide a destination for the download using
Download::set_destination(). If this signal is not
handled, the file will be downloaded to G_USER_DIRECTORY_DOWNLOAD
directory using suggested_filename.
Since 2.40, you may handle this signal asynchronously by
returning true without calling Download::set_destination().
This indicates intent to eventually call Download::set_destination().
In this case, the download will not proceed until the destination is set
or cancelled with Download::cancel().
failed
This signal is emitted when an error occurs during the download
operation. The given error, of the domain WEBKIT_DOWNLOAD_ERROR,
contains further details of the failure. If the download is cancelled
with Download::cancel(), this signal is emitted with error
DownloadError::CancelledByUser. The download operation finishes
after an error and finished signal is emitted after this one.
finished
This signal is emitted when download finishes successfully or due to an error.
In case of errors failed signal is emitted before this one.
received-data
This signal is emitted after response is received, every time new data has been written to the destination. It’s useful to know the progress of the download operation.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Download
impl Download
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancels the download.
When the ongoing download
operation is effectively cancelled the signal
failed is emitted with
DownloadError::CancelledByUser error.
Sourcepub fn allows_overwrite(&self) -> bool
pub fn allows_overwrite(&self) -> bool
Returns the current value of the allow-overwrite property.
Returns the current value of the allow-overwrite property,
which determines whether the download will overwrite an existing file on
disk, or if it will fail if the destination already exists.
Returns
the current value of the allow-overwrite property
Sourcepub fn destination(&self) -> Option<GString>
pub fn destination(&self) -> Option<GString>
Obtains the destination to which the downloaded file will be written.
You can connect to created-destination to make
sure this method returns a valid destination.
Returns
the destination or None
Sourcepub fn elapsed_time(&self) -> f64
pub fn elapsed_time(&self) -> f64
Gets the elapsed time in seconds, including any fractional part.
If the download finished, had an error or was cancelled this is the time between its start and the event.
Returns
seconds since the download was started
Sourcepub fn estimated_progress(&self) -> f64
pub fn estimated_progress(&self) -> f64
Gets the value of the estimated-progress property.
Gets the value of the estimated-progress property.
You can monitor the estimated progress of the download operation by
connecting to the notify::estimated-progress signal of self.
Returns
an estimate of the of the percent complete for a download as a range from 0.0 to 1.0.
Sourcepub fn received_data_length(&self) -> u64
pub fn received_data_length(&self) -> u64
Gets the length of the data already downloaded for self.
Gets the length of the data already downloaded for self
in bytes.
Returns
the amount of bytes already downloaded.
Sourcepub fn request(&self) -> Option<URIRequest>
pub fn request(&self) -> Option<URIRequest>
Sourcepub fn response(&self) -> Option<URIResponse>
pub fn response(&self) -> Option<URIResponse>
Retrieves the URIResponse object that backs the download process.
Retrieves the URIResponse object that backs the download
process. This method returns None if called before the response
is received from the server. You can connect to notify::response
signal to be notified when the response is received.
Returns
the URIResponse, or None if
the response hasn’t been received yet.
Sourcepub fn set_allow_overwrite(&self, allowed: bool)
pub fn set_allow_overwrite(&self, allowed: bool)
Sets the allow-overwrite property.
Sets the allow-overwrite property, which determines whether
the download may overwrite an existing file on disk, or if it will fail if
the destination already exists.
allowed
the new value for the allow-overwrite property
Sourcepub fn set_destination(&self, destination: &str)
pub fn set_destination(&self, destination: &str)
Sets the destination to which the downloaded file will be written.
This method should be called before the download transfer
starts or it will not have any effect on the ongoing download
operation. To set the destination using the filename suggested
by the server connect to decide-destination
signal and call set_destination(). If you want to
set a fixed destination that doesn’t depend on the suggested
filename you can connect to notify::response signal and call
set_destination().
If decide-destination signal is not handled
and destination is not set when the download transfer starts,
the file will be saved with the filename suggested by the server in
G_USER_DIRECTORY_DOWNLOAD directory.
destination
the destination
Sourcepub fn connect_created_destination<F: Fn(&Self, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_created_destination<F: Fn(&Self, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted after decide-destination and before
received-data to notify that destination file has been
created successfully at destination.
destination
the destination
Sourcepub fn connect_decide_destination<F: Fn(&Self, &str) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_decide_destination<F: Fn(&Self, &str) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted after response is received to
decide a destination for the download using
set_destination(). If this signal is not
handled, the file will be downloaded to G_USER_DIRECTORY_DOWNLOAD
directory using suggested_filename.
Since 2.40, you may handle this signal asynchronously by
returning true without calling set_destination().
This indicates intent to eventually call set_destination().
In this case, the download will not proceed until the destination is set
or cancelled with cancel().
suggested_filename
the filename suggested for the download
Returns
true to stop other handlers from being invoked for the event,
or false to propagate the event further.
Sourcepub fn connect_failed<F: Fn(&Self, &Error) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_failed<F: Fn(&Self, &Error) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when an error occurs during the download
operation. The given error, of the domain WEBKIT_DOWNLOAD_ERROR,
contains further details of the failure. If the download is cancelled
with cancel(), this signal is emitted with error
DownloadError::CancelledByUser. The download operation finishes
after an error and finished signal is emitted after this one.
error
the glib::Error that was triggered
Sourcepub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
This signal is emitted when download finishes successfully or due to an error.
In case of errors failed signal is emitted before this one.
Sourcepub fn connect_received_data<F: Fn(&Self, u64) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_received_data<F: Fn(&Self, u64) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted after response is received, every time new data has been written to the destination. It’s useful to know the progress of the download operation.
data_length
the length of data received in bytes
pub fn connect_allow_overwrite_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_destination_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_estimated_progress_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_response_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId