pub struct FaviconDatabase { /* private fields */ }Expand description
Provides access to the icons associated with web sites.
WebKit will automatically look for available icons in <link>
elements on opened pages as well as an existing favicon.ico and
load the images found into a memory cache if possible. That cache
is frozen to an on-disk database for persistence.
If enable-private-browsing is true, new icons
won’t be added to the on-disk database and no existing icons will
be deleted from it. Nevertheless, WebKit will still store them in
the in-memory cache during the current execution.
Signals
favicon-changed
This signal is emitted when the favicon URI of page_uri has
been changed to favicon_uri in the database. You can connect
to this signal and call FaviconDatabase::favicon()
to get the favicon. If you are interested in the favicon of a
WebView it’s easier to use the favicon
property. See WebViewExt::favicon() for more details.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FaviconDatabase
impl FaviconDatabase
Sourcepub fn favicon<P: FnOnce(Result<Texture, Error>) + 'static>(
&self,
page_uri: &str,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn favicon<P: FnOnce(Result<Texture, Error>) + 'static>( &self, page_uri: &str, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously obtains a favicon image.
Asynchronously obtains an image of the favicon for the given page URI. It returns the cached icon if it’s in the database asynchronously waiting for the icon to be read from the database.
This is an asynchronous method. When the operation is finished, callback will
be invoked. You can then call webkit_favicon_database_get_favicon_finish()
to get the result of the operation.
page_uri
URI of the page for which we want to retrieve the favicon
cancellable
A gio::Cancellable or None.
callback
A GAsyncReadyCallback to call when the request is
satisfied or None if you don’t care about the result.
pub fn favicon_future( &self, page_uri: &str, ) -> Pin<Box_<dyn Future<Output = Result<Texture, Error>> + 'static>>
Sourcepub fn favicon_uri(&self, page_uri: &str) -> Option<GString>
pub fn favicon_uri(&self, page_uri: &str) -> Option<GString>
Sourcepub fn connect_favicon_changed<F: Fn(&Self, &str, &str) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_favicon_changed<F: Fn(&Self, &str, &str) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when the favicon URI of page_uri has
been changed to favicon_uri in the database. You can connect
to this signal and call favicon()
to get the favicon. If you are interested in the favicon of a
WebView it’s easier to use the favicon
property. See WebViewExt::favicon() for more details.
page_uri
the URI of the Web page containing the icon
favicon_uri
the URI of the favicon