pub struct FileChooserRequest { /* private fields */ }Expand description
A request to open a file chooser.
Whenever the user interacts with an HTML input element with
file type, WebKit will need to show a dialog to choose one or
more files to be uploaded to the server along with the rest of the
form data. For that to happen in a general way, instead of just
opening a GtkFileChooserDialog (which might be not desirable in
some cases, which could prefer to use their own file chooser
dialog), WebKit will fire the run-file-chooser
signal with a FileChooserRequest object, which will allow
the client application to specify the files to be selected, to
inspect the details of the request (e.g. if multiple selection
should be allowed) and to cancel the request, in case nothing was
selected.
In case the client application does not wish to handle this signal,
WebKit will provide a default handler which will asynchronously run
a regular GtkFileChooserDialog for the user to interact with.
Properties
filter
The filter currently associated with the request. See
FileChooserRequest::mime_types_filter() for more
details.
Readable
mime-types
A None-terminated array of strings containing the list of MIME
types the file chooser dialog should handle. See
FileChooserRequest::mime_types() for more details.
Readable
select-multiple
Whether the file chooser should allow selecting multiple
files. See
FileChooserRequest::selects_multiple() for
more details.
Readable
selected-files
A None-terminated array of strings containing the list of
selected files associated to the current request. See
FileChooserRequest::selected_files() for more details.
Readable
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FileChooserRequest
impl FileChooserRequest
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Ask WebKit to cancel the request.
It’s important to do this in case no selection has been made in the client, otherwise the request won’t be properly completed and the browser will keep the request pending forever, which might cause the browser to hang.
Sourcepub fn mime_types(&self) -> Vec<GString>
pub fn mime_types(&self) -> Vec<GString>
Get the list of MIME types the file chooser dialog should handle.
Get the list of MIME types the file chooser dialog should handle, in the format specified in RFC 2046 for “media types”. Its contents depend on the value of the ‘accept’ attribute for HTML input elements. This function should normally be called before presenting the file chooser dialog to the user, to decide whether to allow the user to select multiple files at once or only one.
Returns
a
None-terminated array of strings if a list of accepted MIME types
is defined or None otherwise, meaning that any MIME type should be
accepted. This array and its contents are owned by WebKit and
should not be modified or freed.
Sourcepub fn mime_types_filter(&self) -> Option<FileFilter>
pub fn mime_types_filter(&self) -> Option<FileFilter>
Get the filter currently associated with the request.
Get the filter currently associated with the request, ready to be
used by GtkFileChooser. This function should normally be called
before presenting the file chooser dialog to the user, to decide
whether to apply a filter so the user would not be allowed to
select files with other MIME types.
See mime_types() if you are
interested in getting the list of accepted MIME types.
Returns
a gtk::FileFilter if a list of accepted
MIME types is defined or None otherwise. The returned object is
owned by WebKit should not be modified or freed.
Sourcepub fn selects_multiple(&self) -> bool
pub fn selects_multiple(&self) -> bool
Whether the file chooser should allow selecting multiple files.
Determine whether the file chooser associated to this
FileChooserRequest should allow selecting multiple files,
which depends on the HTML input element having a ‘multiple’
attribute defined.
Returns
true if the file chooser should allow selecting multiple files or false otherwise.
Sourcepub fn selected_files(&self) -> Vec<GString>
pub fn selected_files(&self) -> Vec<GString>
Get the list of selected files associated to the request.
Get the list of selected files currently associated to the request. Initially, the return value of this method contains any files selected in previous file chooser requests for this HTML input element. Once webkit_file_chooser_request_select_files, the value will reflect whatever files are given.
This function should normally be called only before presenting the file chooser dialog to the user, to decide whether to perform some extra action, like pre-selecting the files from a previous request.
Returns
a
None-terminated array of strings if there are selected files
associated with the request or None otherwise. This array and its
contents are owned by WebKit and should not be modified or
freed.
Sourcepub fn select_files(&self, files: &[&str])
pub fn select_files(&self, files: &[&str])
Sourcepub fn filter(&self) -> Option<FileFilter>
pub fn filter(&self) -> Option<FileFilter>
The filter currently associated with the request. See
mime_types_filter() for more
details.
pub fn connect_filter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_mime_types_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_select_multiple_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selected_files_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId