pub struct FormSubmissionRequest { /* private fields */ }Expand description
Represents a form submission request.
When a form is about to be submitted in a WebView, the
submit-form signal is emitted. Its request argument
contains information about the text fields of the form, that are
typically used to store login information, returned as lists by
list_text_fields(). You can submit the
form with submit().
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl FormSubmissionRequest
impl FormSubmissionRequest
Sourcepub fn list_text_fields(&self) -> Option<(Vec<GString>, Vec<GString>)>
pub fn list_text_fields(&self) -> Option<(Vec<GString>, Vec<GString>)>
Get lists of the text fields contained in the form associated to self.
Get lists with the names and values of the text fields contained in
the form associated to self. Note that names and values may be
None.
If this function returns false, then both field_names and
field_values will be empty.
Returns
true if the form contains text fields, or false otherwise
field_names
names of the text fields in the form
field_values
values of the text fields in the form