pub struct InputMethodContext { /* private fields */ }Expand description
Base class for input method contexts.
WebKitInputMethodContext defines the interface to implement WebKit input methods. The input methods are used by WebKit, when editable content is focused, to map from key events to Unicode character strings.
An input method may consume multiple key events in sequence and finally output the composed result. This is called preediting, and an input method may provide feedback about this process by displaying the intermediate composition states as preedit text.
This is an Abstract Base Class, you cannot instantiate it.
Properties
input-hints
The #WebKitInputHints of the input associated with this context.
Readable | Writeable
input-purpose
The #WebKitInputPurpose of the input associated with this context.
Readable | Writeable
Signals
committed
Emitted when a complete input sequence has been entered by the user. This can be a single character immediately after a key press or the final result of preediting.
delete-surrounding
Emitted when the input method wants to delete the context surrounding the cursor. If @offset is a negative value, it means a position before the cursor.
preedit-changed
Emitted whenever the preedit sequence currently being entered has changed. It is also emitted at the end of a preedit sequence, in which case webkit_input_method_context_get_preedit() returns the empty string.
preedit-finished
Emitted when a preediting sequence has been completed or canceled.
preedit-started
Emitted when a new preediting sequence starts.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl InputMethodContext
impl InputMethodContext
pub const NONE: Option<&'static InputMethodContext> = None