MemoryPressureSettings

Struct MemoryPressureSettings 

pub struct MemoryPressureSettings { /* private fields */ }
A boxed type representing the settings for the memory pressure handler

MemoryPressureSettings is a boxed type that can be used to provide some custom settings to control how the memory pressure situations are handled by the different processes.

The memory pressure system implemented inside the different process will try to keep the memory usage under the defined memory limit. In order to do that, it will check the used memory with a user defined frequency and decide whether it should try to release memory. The thresholds passed will define how urgent is to release that memory.

Take into account that badly defined parameters can greatly reduce the performance of the engine. For example, setting memory limit too low with a fast poll interval can cause the process to constantly be trying to release memory.

A MemoryPressureSettings can be passed to a WebContext constructor, and the settings will be applied to all the web processes created by that context.

A MemoryPressureSettings can be passed to webkit_website_data_manager_set_memory_pressure_settings(), and the settings will be applied to all the network processes created after that call by any instance of WebsiteDataManager.

GLib type: Boxed type with copy-on-clone semantics.

Implementations

Source

impl MemoryPressureSettings

pub fn as_ptr(&self) -> *mut WebKitMemoryPressureSettings

Return the inner pointer to the underlying C value.

pub unsafe fn from_glib_ptr_borrow( ptr: &*mut WebKitMemoryPressureSettings, ) -> &Self

Borrows the underlying C value.

pub unsafe fn from_glib_ptr_borrow_mut( ptr: &mut *mut WebKitMemoryPressureSettings, ) -> &mut Self

Borrows the underlying C value mutably.

Source

impl MemoryPressureSettings

pub fn new() -> MemoryPressureSettings

Create a new MemoryPressureSettings with the default values.

Returns

A new MemoryPressureSettings instance filled with the default values.

pub fn conservative_threshold(&mut self) -> f64

Gets the conservative memory usage threshold.

Returns

value in the (0, 1) range.

pub fn kill_threshold(&mut self) -> f64

Gets the kill memory usage threshold.

Returns

positive value, can be zero.

pub fn memory_limit(&mut self) -> u32

Gets the memory usage limit.

Returns

current value, in megabytes.

pub fn poll_interval(&mut self) -> f64

Gets the interval at which memory usage is checked.

Returns

current interval value, in seconds.

pub fn strict_threshold(&mut self) -> f64

Gets the strict memory usage threshold.

Returns

value in the (0, 1) range.

pub fn set_conservative_threshold(&mut self, value: f64)

Sets the memory limit for the conservative policy to start working.

Sets value as the fraction of the defined memory limit where the conservative policy starts working. This policy will try to reduce the memory footprint by releasing non critical memory.

The threshold must be bigger than 0 and smaller than 1, and it must be smaller than the strict threshold defined in self. The default value is 0.33.

value

fraction of the memory limit where the conservative policy starts working.

pub fn set_kill_threshold(&mut self, value: f64)

Sets value as the fraction of the defined memory limit where the process will be killed.

The threshold must be a value bigger or equal to 0. A value of 0 means that the process is never killed. If the threshold is not 0, then it must be bigger than the strict threshold defined in self. The threshold can also have values bigger than 1. The default value is 0.

value

fraction of the memory limit where the process will be killed because of excessive memory usage.

pub fn set_memory_limit(&mut self, memory_limit: u32)

Sets memory_limit the memory limit value to self.

The default value is the system’s RAM size with a maximum of 3GB.

memory_limit

amount of memory (in MB) that the process is allowed to use.

pub fn set_poll_interval(&mut self, value: f64)

Sets value as the poll interval used by self.

The poll interval value must be bigger than 0. The default value is 30 seconds.

value

period (in seconds) between memory usage measurements.

pub fn set_strict_threshold(&mut self, value: f64)

Sets the memory limit for the strict policy to start working.

Sets value as the fraction of the defined memory limit where the strict policy starts working. This policy will try to reduce the memory footprint by releasing critical memory.

The threshold must be bigger than 0 and smaller than 1. Also, it must be bigger than the conservative threshold defined in self, and smaller than the kill threshold if the latter is not 0. The default value is 0.5.

value

fraction of the memory limit where the strict policy starts working.