pub struct NavigationAction { /* private fields */ }Expand description
Provides details about interaction resulting in a resource load.
GLib type: Boxed type with copy-on-clone semantics.
Implementations
Sourcepub fn as_ptr(&self) -> *mut WebKitNavigationAction
pub fn as_ptr(&self) -> *mut WebKitNavigationAction
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitNavigationAction) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitNavigationAction) -> &Self
Borrows the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow_mut(
ptr: &mut *mut WebKitNavigationAction,
) -> &mut Self
pub unsafe fn from_glib_ptr_borrow_mut( ptr: &mut *mut WebKitNavigationAction, ) -> &mut Self
Borrows the underlying C value mutably.
Sourcepub fn frame_name(&self) -> Option<GString>
pub fn frame_name(&self) -> Option<GString>
Gets the self target frame name. For example if navigation was triggered by clicking a
link with a target attribute equal to “_blank”, this will return the value of that attribute.
In all other cases this function will return None.
Returns
The name of the new frame this navigation action targets or None
Sourcepub fn modifiers(&self) -> u32
pub fn modifiers(&self) -> u32
Return the modifier keys.
Return a bitmask of GdkModifierType values describing the modifier keys that were in effect
when the navigation was requested
Returns
the modifier keys
Return the number of the mouse button that triggered the navigation.
Return the number of the mouse button that triggered the navigation, or 0 if the navigation was not started by a mouse event.
Returns
the mouse button number or 0
Sourcepub fn request(&self) -> Option<URIRequest>
pub fn request(&self) -> Option<URIRequest>
Return the URIRequest associated with the navigation action.
Modifications to the returned object are <emphasis>not</emphasis> taken
into account when the request is sent over the network, and is intended
only to aid in evaluating whether a navigation action should be taken or
not. To modify requests before they are sent over the network the
WebKitPage::send-request signal can be used instead.
Returns
Sourcepub fn is_redirect(&self) -> bool
pub fn is_redirect(&self) -> bool
Sourcepub fn is_user_gesture(&self) -> bool
pub fn is_user_gesture(&self) -> bool
Return whether the navigation was triggered by a user gesture like a mouse click.
Returns
whether navigation action is a user gesture