NetworkSession

Struct NetworkSession 

pub struct NetworkSession { /* private fields */ }
Manages network configuration.

Properties

cache-directory

The base caches directory used to create the WebsiteDataManager. If None, a default location will be used.

Writeable | Construct Only

data-directory

The base data directory used to create the WebsiteDataManager. If None, a default location will be used.

Writeable | Construct Only

is-ephemeral

Whether to create an ephermeral WebsiteDataManager for the session.

Readable | Writeable | Construct Only

Signals

download-started

This signal is emitted when a new download request is made.

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl NetworkSession

pub fn new( data_directory: Option<&str>, cache_directory: Option<&str>, ) -> NetworkSession

Creates a new NetworkSession with a persistent WebsiteDataManager. The parameters data_directory and cache_directory will be used as construct properties of the WebsiteDataManager of the network session. Note that if None is passed, the default directory will be passed to WebsiteDataManager so that WebsiteDataManager::base_data_directory() and WebsiteDataManager::base_cache_directory() always return a value for non ephemeral sessions.

It must be passed as construct parameter of a WebView.

data_directory

a base directory for data, or None

cache_directory

a base directory for caches, or None

Returns

the newly created NetworkSession

pub fn new_ephemeral() -> NetworkSession

Creates a new NetworkSession with an ephemeral WebsiteDataManager.

Returns

a new ephemeral NetworkSession.

pub fn builder() -> NetworkSessionBuilder

Creates a new builder-pattern struct instance to construct NetworkSession objects.

This method returns an instance of NetworkSessionBuilder which can be used to create NetworkSession objects.

pub fn allow_tls_certificate_for_host( &self, certificate: &impl IsA<TlsCertificate>, host: &str, )

Ignore further TLS errors on the host for the certificate present in info.

If host is an IPv6 address, it should not be surrounded by brackets. This expectation matches g_uri_get_host().

certificate

a gio::TlsCertificate

host

the host for which a certificate is to be allowed

pub fn download_uri(&self, uri: &str) -> Option<Download>

Requests downloading of the specified URI string.

The download operation will not be associated to any WebView, if you are interested in starting a download from a particular WebView use WebViewExt::download_uri() instead.

uri

the URI to download

Returns

a new Download representing the download operation.

pub fn cookie_manager(&self) -> Option<CookieManager>

Get the CookieManager of self.

Returns

a CookieManager

pub fn is_itp_enabled(&self) -> bool

Get whether Intelligent Tracking Prevention (ITP) is enabled or not.

Returns

true if ITP is enabled, or false otherwise.

pub fn itp_summary<P: FnOnce(Result<Vec<ITPThirdParty>, Error>) + 'static>( &self, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )

Asynchronously get the list of ITPThirdParty seen for self.

Every ITPThirdParty contains the list of ITPFirstParty under which it has been seen.

When the operation is finished, callback will be called. You can then call webkit_network_session_get_itp_summary_finish() to get the result of the operation.

cancellable

a gio::Cancellable or None to ignore

callback

a GAsyncReadyCallback to call when the request is satisfied

pub fn itp_summary_future( &self, ) -> Pin<Box_<dyn Future<Output = Result<Vec<ITPThirdParty>, Error>> + 'static>>

pub fn is_persistent_credential_storage_enabled(&self) -> bool

Get whether persistent credential storage is enabled or not.

See also set_persistent_credential_storage_enabled().

Returns

true if persistent credential storage is enabled, or false otherwise.

pub fn tls_errors_policy(&self) -> TLSErrorsPolicy

Get the TLS errors policy of self.

Returns

a TLSErrorsPolicy

pub fn website_data_manager(&self) -> Option<WebsiteDataManager>

Get the WebsiteDataManager of self.

Returns

a WebsiteDataManager

pub fn is_ephemeral(&self) -> bool

Get whether self is ephemeral. A NetworkSession is ephemeral when its WebsiteDataManager is ephemeral. See is-ephemeral for more details.

Returns

true if self is pehmeral, or false otherwise

pub fn prefetch_dns(&self, hostname: &str)

Resolve the domain name of the given hostname in advance, so that if a URI of hostname is requested the load will be performed more quickly.

hostname

a hostname to be resolved

pub fn set_itp_enabled(&self, enabled: bool)

Enable or disable Intelligent Tracking Prevention (ITP).

When ITP is enabled resource load statistics are collected and used to decide whether to allow or block third-party cookies and prevent user tracking. Note that while ITP is enabled the accept policy CookieAcceptPolicy::NoThirdParty is ignored and CookieAcceptPolicy::Always is used instead. See also webkit_cookie_session_set_accept_policy().

enabled

value to set

pub fn set_persistent_credential_storage_enabled(&self, enabled: bool)

Enable or disable persistent credential storage.

When enabled, which is the default for non-ephemeral sessions, the network process will try to read and write HTTP authentiacation credentials from persistent storage.

enabled

value to set

pub fn set_proxy_settings( &self, proxy_mode: NetworkProxyMode, proxy_settings: Option<&NetworkProxySettings>, )

Set the network proxy settings to be used by connections started in self session.

By default NetworkProxyMode::Default is used, which means that the system settings will be used (g_proxy_resolver_get_default()). If you want to override the system default settings, you can either use NetworkProxyMode::NoProxy to make sure no proxies are used at all, or NetworkProxyMode::Custom to provide your own proxy settings. When proxy_mode is NetworkProxyMode::Custom proxy_settings must be a valid NetworkProxySettings; otherwise, proxy_settings must be None.

proxy_mode

a NetworkProxyMode

proxy_settings

a NetworkProxySettings, or None

pub fn set_tls_errors_policy(&self, policy: TLSErrorsPolicy)

Set the TLS errors policy of self as policy.

policy

a TLSErrorsPolicy

pub fn default() -> Option<NetworkSession>

Get the default network session. The default network session is created using new() and passing None as data and cache directories.

Returns

a NetworkSession

pub fn set_memory_pressure_settings(settings: &mut MemoryPressureSettings)

Sets settings as the MemoryPressureSettings.

Sets settings as the MemoryPressureSettings to be used by the network process created by any instance of NetworkSession after this function is called.

Be sure to call this function before creating any NetworkSession.

The periodic check for used memory is disabled by default on network processes. This will be enabled only if custom settings have been set using this function. After that, in order to remove the custom settings and disable the periodic check, this function must be called passing None as the value of settings.

settings

a WebKitMemoryPressureSettings.

pub fn connect_download_started<F: Fn(&Self, &Download) + 'static>( &self, f: F, ) -> SignalHandlerId

This signal is emitted when a new download request is made.

download

the Download associated with this event