pub struct OptionMenu { /* private fields */ }Expand description
Represents the dropdown menu of a select element in a WebView.
When a select element in a WebView needs to display a dropdown menu, the signal
show-option-menu is emitted, providing a WebKitOptionMenu with the
OptionMenuItems that should be displayed.
Signals
close
Emitted when closing a OptionMenu is requested. This can happen
when the user explicitly calls OptionMenu::close() or when the
element is detached from the current page.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl OptionMenu
impl OptionMenu
Sourcepub fn activate_item(&self, index: u32)
pub fn activate_item(&self, index: u32)
Activates the OptionMenuItem at index in self.
Activating an item changes the value
of the element making the item the active one. You are expected to close the menu with
close() after activating an item, calling this function again will have no
effect.
index
the index of the item
Sourcepub fn close(&self)
pub fn close(&self)
Request to close a OptionMenu.
This emits WebKitOptionMenu::close signal.
This function should always be called to notify WebKit that the associated
menu has been closed. If the menu is closed and neither select_item()
nor activate_item() have been called, the element value remains
unchanged.
Sourcepub fn event(&self) -> Option<Event>
pub fn event(&self) -> Option<Event>
Gets the gdk::Event that triggered the dropdown menu.
If self was not triggered by a user interaction, like a mouse click,
None is returned.
Returns
the menu event or None.
Sourcepub fn item(&self, index: u32) -> Option<OptionMenuItem>
pub fn item(&self, index: u32) -> Option<OptionMenuItem>
Returns the OptionMenuItem at index in self.
index
the index of the item
Returns
a OptionMenuItem of self.
Sourcepub fn select_item(&self, index: u32)
pub fn select_item(&self, index: u32)
Selects the OptionMenuItem at index in self.
Selecting an item changes the
text shown by the combo button, but it doesn’t change the value of the element. You need to
explicitly activate the item with select_item() or close the menu with
close() in which case the currently selected item will be activated.
index
the index of the item
Sourcepub fn connect_close<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_close<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when closing a OptionMenu is requested. This can happen
when the user explicitly calls close() or when the
element is detached from the current page.