pub struct PermissionStateQuery { /* private fields */ }Expand description
This query represents a user’s choice to allow or deny access to “powerful features” of the platform, as specified in the Permissions W3C Specification.
When signalled by the WebView through the query-permission-state signal, the application
has to eventually respond, via [finish()][Self::finish()], whether it grants,
denies or requests a dedicated permission prompt for the given query.
When a PermissionStateQuery is not handled by the user, the user-agent is instructed to
prompt the user for the given permission.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl PermissionStateQuery
impl PermissionStateQuery
Sourcepub fn as_ptr(&self) -> *mut WebKitPermissionStateQuery
pub fn as_ptr(&self) -> *mut WebKitPermissionStateQuery
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(
ptr: &*mut WebKitPermissionStateQuery,
) -> &Self
pub unsafe fn from_glib_ptr_borrow( ptr: &*mut WebKitPermissionStateQuery, ) -> &Self
Borrows the underlying C value.
Sourceimpl PermissionStateQuery
impl PermissionStateQuery
Sourcepub fn finish(&self, state: PermissionState)
pub fn finish(&self, state: PermissionState)
Notify the web-engine of the selected permission state for the given query. This function should
only be called as a response to the WebKitWebView::query-permission-state signal.
state
Sourcepub fn security_origin(&self) -> Option<SecurityOrigin>
pub fn security_origin(&self) -> Option<SecurityOrigin>
Get the permission origin for which access is being queried.
Returns
A SecurityOrigin representing the origin from which the
self was emitted.