pub struct PrintOperation { /* private fields */ }Expand description
Controls a print operation.
A PrintOperation controls a print operation in WebKit. With
a similar API to GtkPrintOperation, it lets you set the print
settings with set_print_settings() or
display the print dialog with run_dialog().
Properties
page-setup
The initial gtk::PageSetup for the print operation.
Readable | Writeable
print-settings
The initial gtk::PrintSettings for the print operation.
Readable | Writeable
web-view
The WebView that will be printed.
Readable | Writeable | Construct Only
Signals
failed
Emitted when an error occurs while printing. The given error, of the domain
WEBKIT_PRINT_ERROR, contains further details of the failure.
The finished signal is emitted after this one.
finished
Emitted when the print operation has finished doing everything required for printing.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl PrintOperation
impl PrintOperation
Sourcepub fn new(web_view: &impl IsA<WebView>) -> PrintOperation
pub fn new(web_view: &impl IsA<WebView>) -> PrintOperation
Create a new PrintOperation to print web_view contents.
web_view
a WebView
Returns
a new PrintOperation.
Sourcepub fn builder() -> PrintOperationBuilder
pub fn builder() -> PrintOperationBuilder
Creates a new builder-pattern struct instance to construct PrintOperation objects.
This method returns an instance of PrintOperationBuilder which can be used to create PrintOperation objects.
Sourcepub fn page_setup(&self) -> Option<PageSetup>
pub fn page_setup(&self) -> Option<PageSetup>
Return the current page setup of self.
It returns None until
either set_page_setup() or run_dialog()
have been called.
Returns
the current gtk::PageSetup of self.
Sourcepub fn print_settings(&self) -> Option<PrintSettings>
pub fn print_settings(&self) -> Option<PrintSettings>
Return the current print settings of self.
It returns None until
either set_print_settings() or run_dialog()
have been called.
Returns
the current gtk::PrintSettings of self.
Sourcepub fn print(&self)
pub fn print(&self)
Start a print operation using current print settings and page setup.
Start a print operation using current print settings and page setup
without showing the print dialog. If either print settings or page setup
are not set with set_print_settings() and
set_page_setup(), the default options will be used
and the print job will be sent to the default printer.
The finished signal is emitted when the printing
operation finishes. If an error occurs while printing the signal
failed is emitted before finished.
If the app is running in a sandbox, this function only works if printing to a file that is in a location accessible to the sandbox, usually acquired through the File Chooser portal. This function will not work for physical printers when running in a sandbox.
Sourcepub fn run_dialog(
&self,
parent: Option<&impl IsA<Window>>,
) -> PrintOperationResponse
pub fn run_dialog( &self, parent: Option<&impl IsA<Window>>, ) -> PrintOperationResponse
Run the print dialog and start printing.
Run the print dialog and start printing using the options selected by
the user. This method returns when the print dialog is closed.
If the print dialog is cancelled PrintOperationResponse::Cancel
is returned. If the user clicks on the print button, PrintOperationResponse::Print
is returned and the print operation starts. In this case, the finished
signal is emitted when the operation finishes. If an error occurs while printing, the signal
failed is emitted before finished.
If the print dialog is not cancelled current print settings and page setup of self
are updated with options selected by the user when Print button is pressed in print dialog.
You can get the updated print settings and page setup by calling
print_settings() and page_setup()
after this method.
parent
transient parent of the print dialog
Returns
the PrintOperationResponse of the print dialog
Sourcepub fn set_page_setup(&self, page_setup: &PageSetup)
pub fn set_page_setup(&self, page_setup: &PageSetup)
Set the current page setup of self.
Current page setup is used for the
initial values of the print dialog when run_dialog() is called.
page_setup
a gtk::PageSetup to set
Sourcepub fn set_print_settings(&self, print_settings: &PrintSettings)
pub fn set_print_settings(&self, print_settings: &PrintSettings)
Set the current print settings of self.
Set the current print settings of self. Current print settings are used for
the initial values of the print dialog when run_dialog() is called.
print_settings
a gtk::PrintSettings to set
Sourcepub fn connect_failed<F: Fn(&Self, &Error) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_failed<F: Fn(&Self, &Error) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when an error occurs while printing. The given error, of the domain
WEBKIT_PRINT_ERROR, contains further details of the failure.
The finished signal is emitted after this one.
error
the glib::Error that was triggered
Sourcepub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the print operation has finished doing everything required for printing.
pub fn connect_page_setup_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_print_settings_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId