pub struct ResponsePolicyDecision { /* private fields */ }Expand description
A policy decision for resource responses.
WebKitResponsePolicyDecision represents a policy decision for a resource response, whether from the network or the local system. A very common use case for these types of decision is deciding whether or not to download a particular resource or to load it normally.
Properties
request
This property contains the #WebKitURIRequest associated with this policy decision.
Readable
response
This property contains the #WebKitURIResponse associated with this policy decision.
Readable
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ResponsePolicyDecision
impl ResponsePolicyDecision
Sourcepub fn request(&self) -> Option<URIRequest>
pub fn request(&self) -> Option<URIRequest>
Return the #WebKitURIRequest associated with the response decision.
Modifications to the returned object are
Returns
The URI request that is associated with this policy decision.
Sourcepub fn response(&self) -> Option<URIResponse>
pub fn response(&self) -> Option<URIResponse>
Gets the value of the #WebKitResponsePolicyDecision:response property.
Returns
The URI response that is associated with this policy decision.
Sourcepub fn is_main_frame_main_resource(&self) -> bool
pub fn is_main_frame_main_resource(&self) -> bool
Sourcepub fn is_mime_type_supported(&self) -> bool
pub fn is_mime_type_supported(&self) -> bool
Gets whether the MIME type of the response can be displayed in the #WebKitWebView.
Gets whether the MIME type of the response can be displayed in the #WebKitWebView that triggered this policy decision request. See also webkit_web_view_can_show_mime_type().
Returns
true if the MIME type of the response is supported or false otherwise
pub fn connect_request_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_response_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId