pub struct ScriptDialog { /* private fields */ }Expand description
Carries details to be shown in user-facing dialogs.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl ScriptDialog
impl ScriptDialog
Sourcepub fn as_ptr(&self) -> *mut WebKitScriptDialog
pub fn as_ptr(&self) -> *mut WebKitScriptDialog
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitScriptDialog) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitScriptDialog) -> &Self
Borrows the underlying C value.
Sourceimpl ScriptDialog
impl ScriptDialog
Sourcepub fn close(&self)
pub fn close(&self)
Close @self.
When handling a #WebKitScriptDialog asynchronously (webkit_script_dialog_ref() was called in #WebKitWebView::script-dialog callback), this function needs to be called to notify that we are done with the script dialog. The dialog will be closed on destruction if this function hasn’t been called before.
Sourcepub fn confirm_set_confirmed(&self, confirmed: bool)
pub fn confirm_set_confirmed(&self, confirmed: bool)
Set whether the user confirmed the dialog.
This method is used for ScriptDialogType::Confirm and ScriptDialogType::BeforeUnloadConfirm dialogs when
#WebKitWebView::script-dialog signal is emitted to set whether the user
confirmed the dialog or not. The default implementation of #WebKitWebView::script-dialog
signal sets true when the OK or Stay buttons are clicked and false otherwise.
It’s an error to use this method with a #WebKitScriptDialog that is not of type
ScriptDialogType::Confirm or ScriptDialogType::BeforeUnloadConfirm
confirmed
whether user confirmed the dialog
Sourcepub fn dialog_type(&self) -> ScriptDialogType
pub fn dialog_type(&self) -> ScriptDialogType
Sourcepub fn prompt_get_default_text(&self) -> Option<GString>
pub fn prompt_get_default_text(&self) -> Option<GString>
Get the default text of a #WebKitScriptDialog of type ScriptDialogType::Prompt.
It’s an error to use this method with a #WebKitScriptDialog that is not of type
ScriptDialogType::Prompt.
Returns
the default text of @self
Sourcepub fn prompt_set_text(&self, text: &str)
pub fn prompt_set_text(&self, text: &str)
Set the text entered by the user in the dialog.
This method is used for ScriptDialogType::Prompt dialogs when
#WebKitWebView::script-dialog signal is emitted to set the text
entered by the user. The default implementation of #WebKitWebView::script-dialog
signal sets the text of the entry form when OK button is clicked, otherwise None is set.
It’s an error to use this method with a #WebKitScriptDialog that is not of type
ScriptDialogType::Prompt.
text
the text to set