pub struct SecurityOrigin { /* private fields */ }Expand description
A security boundary for websites.
#WebKitSecurityOrigin is a representation of a security domain defined by websites. A security origin consists of a protocol, a hostname, and an optional port number.
Resources with the same security origin can generally access each
other for client-side scripting or database access. When comparing
origins, beware that if both protocol and host are None, the origins
should not be treated as equal.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl SecurityOrigin
impl SecurityOrigin
Sourcepub fn as_ptr(&self) -> *mut WebKitSecurityOrigin
pub fn as_ptr(&self) -> *mut WebKitSecurityOrigin
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitSecurityOrigin) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitSecurityOrigin) -> &Self
Borrows the underlying C value.
Sourceimpl SecurityOrigin
impl SecurityOrigin
Sourcepub fn for_uri(uri: &str) -> SecurityOrigin
pub fn for_uri(uri: &str) -> SecurityOrigin
Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Gets the port of @self.
This function will always return 0 if the port is the default port for the given protocol. For example, http://example.com has the same security origin as http://example.com:80, and this function will return 0 for a #WebKitSecurityOrigin constructed from either URI.
Returns
The port of the #WebKitSecurityOrigin.