pub struct URISchemeRequest { /* private fields */ }Expand description
Represents a URI scheme request.
If you register a particular URI scheme in a WebContext,
using WebContext::register_uri_scheme(), you have to provide
a WebKitURISchemeRequestCallback. After that, when a URI request
is made with that particular scheme, your callback will be
called. There you will be able to access properties such as the
scheme, the URI and path, and the WebView that initiated the
request, and also finish the request with
finish().
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl URISchemeRequest
impl URISchemeRequest
Sourcepub fn finish(
&self,
stream: &impl IsA<InputStream>,
stream_length: i64,
content_type: Option<&str>,
)
pub fn finish( &self, stream: &impl IsA<InputStream>, stream_length: i64, content_type: Option<&str>, )
Finish a URISchemeRequest by setting the contents of the request and its mime type.
stream
a gio::InputStream to read the contents of the request
stream_length
the length of the stream or -1 if not known
content_type
the content type of the stream or None if not known
Sourcepub fn finish_error(&self, error: &mut Error)
pub fn finish_error(&self, error: &mut Error)
Finish a URISchemeRequest with a glib::Error.
error
a glib::Error that will be passed to the WebView
Sourcepub fn finish_with_response(&self, response: &URISchemeResponse)
pub fn finish_with_response(&self, response: &URISchemeResponse)
Sourcepub fn http_body(&self) -> Option<InputStream>
pub fn http_body(&self) -> Option<InputStream>
Sourcepub fn http_headers(&self) -> Option<MessageHeaders>
pub fn http_headers(&self) -> Option<MessageHeaders>
Get the [soup::MessageHeaders][crate::soup::MessageHeaders] of the request.
Returns
the [soup::MessageHeaders][crate::soup::MessageHeaders] of the self.
Sourcepub fn http_method(&self) -> Option<GString>
pub fn http_method(&self) -> Option<GString>