pub struct UserContentManager { /* private fields */ }Expand description
Manages user-defined content which affects web pages.
Using a UserContentManager user CSS style sheets can be set to
be injected in the web pages loaded by a WebView, by
add_style_sheet().
To use a UserContentManager, it must be created using
new(), and then used to construct
a WebView. User style sheets can be created with
UserStyleSheet::new().
User style sheets can be added and removed at any time, but they will affect the web pages loaded afterwards.
Signals
script-message-received
This signal is emitted when JavaScript in a web view calls
<code>window.webkit.messageHandlers.<name>.postMessage()</code>, after registering
<code>``<name>``</code> using
UserContentManager::register_script_message_handler()
Detailed
script-message-with-reply-received
This signal is emitted when JavaScript in a web view calls
<code>window.webkit.messageHandlers.<name>.postMessage()</code>, after registering
<code>``<name>``</code> using
UserContentManager::register_script_message_handler_with_reply()
The given reply can be used to send a return value with
ScriptMessageReply::return_value() or an error message with
ScriptMessageReply::return_error_message(). If none of them are
called, an automatic reply with an undefined value will be sent.
It is possible to handle the reply asynchronously, by simply calling
g_object_ref() on the reply and returning true.
Detailed
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl UserContentManager
impl UserContentManager
Sourcepub fn new() -> UserContentManager
pub fn new() -> UserContentManager
Sourcepub fn add_filter(&self, filter: &UserContentFilter)
pub fn add_filter(&self, filter: &UserContentFilter)
Adds a UserContentFilter to the given UserContentManager.
The same UserContentFilter can be reused with multiple
UserContentManager instances.
Filters need to be saved and loaded from UserContentFilterStore.
filter
Sourcepub fn add_script(&self, script: &UserScript)
pub fn add_script(&self, script: &UserScript)
Adds a UserScript to the given UserContentManager.
The same UserScript can be reused with multiple
UserContentManager instances.
script
Sourcepub fn add_style_sheet(&self, stylesheet: &UserStyleSheet)
pub fn add_style_sheet(&self, stylesheet: &UserStyleSheet)
Adds a UserStyleSheet to the given UserContentManager.
The same UserStyleSheet can be reused with multiple
UserContentManager instances.
stylesheet
Sourcepub fn register_script_message_handler(
&self,
name: &str,
world_name: Option<&str>,
) -> bool
pub fn register_script_message_handler( &self, name: &str, world_name: Option<&str>, ) -> bool
Registers a new user script message handler in script world.
After it is registered,
scripts can use window.webkit.messageHandlers..postMessage(value)
to send messages. Those messages are received by connecting handlers
to the script-message-received signal. The
handler name is used as the detail of the signal. To avoid race
conditions between registering the handler name, and starting to
receive the signals, it is recommended to connect to the signal
before registering the handler name:
⚠️ The following code is in c ⚠️
WebKitWebView *view = webkit_web_view_new ();
WebKitUserContentManager *manager = webkit_web_view_get_user_content_manager ();
g_signal_connect (manager, "script-message-received::foobar",
G_CALLBACK (handle_script_message), NULL);
webkit_user_content_manager_register_script_message_handler (manager, "foobar", "world");Registering a script message handler will fail if the requested name has been already registered before.
If None is passed as the world_name, the default world will be used.
The registered handler can be unregistered by using
unregister_script_message_handler().
name
Name of the script message channel
world_name
the name of a WebKitScriptWorld
Returns
true if message handler was registered successfully, or false otherwise.
Sourcepub fn register_script_message_handler_with_reply(
&self,
name: &str,
world_name: Option<&str>,
) -> bool
pub fn register_script_message_handler_with_reply( &self, name: &str, world_name: Option<&str>, ) -> bool
Registers a new user script message handler in script world with name world_name.
Different from register_script_message_handler(),
when using this function to register the handler, the connected signal is
script-message-with-reply-received, and a reply provided by the user is expected.
Otherwise, the user will receive a default undefined value.
If None is passed as the world_name, the default world will be used.
See register_script_message_handler() for full description.
Registering a script message handler will fail if the requested name has been already registered before.
The registered handler can be unregistered by using
unregister_script_message_handler().
name
Name of the script message channel
world_name
the name of a WebKitScriptWorld
Returns
true if message handler was registered successfully, or false otherwise.
Sourcepub fn remove_all_filters(&self)
pub fn remove_all_filters(&self)
Removes all content filters from the given UserContentManager.
Sourcepub fn remove_all_scripts(&self)
pub fn remove_all_scripts(&self)
Removes all user scripts from the given UserContentManager
See also remove_script().
Sourcepub fn remove_all_style_sheets(&self)
pub fn remove_all_style_sheets(&self)
Removes all user style sheets from the given UserContentManager.
Sourcepub fn remove_filter(&self, filter: &UserContentFilter)
pub fn remove_filter(&self, filter: &UserContentFilter)
Sourcepub fn remove_filter_by_id(&self, filter_id: &str)
pub fn remove_filter_by_id(&self, filter_id: &str)
Removes a filter by the given identifier.
Removes a filter from the given UserContentManager given the
identifier of a UserContentFilter as returned by
UserContentFilter::identifier().
filter_id
Filter identifier
Sourcepub fn remove_script(&self, script: &UserScript)
pub fn remove_script(&self, script: &UserScript)
Sourcepub fn remove_style_sheet(&self, stylesheet: &UserStyleSheet)
pub fn remove_style_sheet(&self, stylesheet: &UserStyleSheet)
Removes a UserStyleSheet from the given UserContentManager.
See also remove_all_style_sheets().
stylesheet
Sourcepub fn unregister_script_message_handler(
&self,
name: &str,
world_name: Option<&str>,
)
pub fn unregister_script_message_handler( &self, name: &str, world_name: Option<&str>, )
Unregisters a previously registered message handler in script world with name world_name.
If None is passed as the world_name, the default world will be used.
Note that this does not disconnect handlers for the
script-message-received signal;
they will be kept connected, but the signal will not be emitted
unless the handler name is registered again.
See also register_script_message_handler().
name
Name of the script message channel
world_name
the name of a WebKitScriptWorld
Sourcepub fn connect_script_message_received<F: Fn(&Self, &Value) + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
pub fn connect_script_message_received<F: Fn(&Self, &Value) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
This signal is emitted when JavaScript in a web view calls
<code>window.webkit.messageHandlers.<name>.postMessage()</code>, after registering
<code>``<name>``</code> using
register_script_message_handler()
value
the value received from the JavaScript world.
Sourcepub fn connect_script_message_with_reply_received<F: Fn(&Self, &Value, &ScriptMessageReply) -> bool + 'static>(
&self,
detail: Option<&str>,
f: F,
) -> SignalHandlerId
pub fn connect_script_message_with_reply_received<F: Fn(&Self, &Value, &ScriptMessageReply) -> bool + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId
This signal is emitted when JavaScript in a web view calls
<code>window.webkit.messageHandlers.<name>.postMessage()</code>, after registering
<code>``<name>``</code> using
register_script_message_handler_with_reply()
The given reply can be used to send a return value with
ScriptMessageReply::return_value() or an error message with
ScriptMessageReply::return_error_message(). If none of them are
called, an automatic reply with an undefined value will be sent.
It is possible to handle the reply asynchronously, by simply calling
g_object_ref() on the reply and returning true.
value
the value received from the JavaScript world.
reply
the ScriptMessageReply to send the reply to the script message.
Returns
true to stop other handlers from being invoked for the event.
false to propagate the event further.