pub struct UserStyleSheet { /* private fields */ }Expand description
A CSS style sheet which can be injected in loaded pages.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl UserStyleSheet
impl UserStyleSheet
Sourcepub fn as_ptr(&self) -> *mut WebKitUserStyleSheet
pub fn as_ptr(&self) -> *mut WebKitUserStyleSheet
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitUserStyleSheet) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitUserStyleSheet) -> &Self
Borrows the underlying C value.
Sourceimpl UserStyleSheet
impl UserStyleSheet
Sourcepub fn new(
source: &str,
injected_frames: UserContentInjectedFrames,
level: UserStyleLevel,
allow_list: &[&str],
block_list: &[&str],
) -> UserStyleSheet
pub fn new( source: &str, injected_frames: UserContentInjectedFrames, level: UserStyleLevel, allow_list: &[&str], block_list: &[&str], ) -> UserStyleSheet
Creates a new user style sheet.
Style sheets can be applied to some URIs
only by passing non-null values for @allow_list or @block_list. Passing a
None allow_list implies that all URIs are on the allow_list. The style
sheet is applied if an URI matches the allow_list and not the block_list.
URI patterns must be of the form [protocol]://[host]/[path], where the
host and path components can contain the wildcard character (*) to
represent zero or more other characters.
source
Source code of the user style sheet.
injected_frames
A #WebKitUserContentInjectedFrames value
level
A #WebKitUserStyleLevel
allow_list
An allow_list of URI patterns or None
block_list
A block_list of URI patterns or None
Returns
A new #WebKitUserStyleSheet
Sourcepub fn for_world(
source: &str,
injected_frames: UserContentInjectedFrames,
level: UserStyleLevel,
world_name: &str,
allow_list: &[&str],
block_list: &[&str],
) -> UserStyleSheet
pub fn for_world( source: &str, injected_frames: UserContentInjectedFrames, level: UserStyleLevel, world_name: &str, allow_list: &[&str], block_list: &[&str], ) -> UserStyleSheet
Creates a new user style sheet for script world.
Creates a new user style sheet for script world with name @world_name. See webkit_user_style_sheet_new() for a full description.
source
Source code of the user style sheet.
injected_frames
A #WebKitUserContentInjectedFrames value
level
A #WebKitUserStyleLevel
world_name
the name of a #WebKitScriptWorld
allow_list
An allow_list of URI patterns or None
block_list
A block_list of URI patterns or None
Returns
A new #WebKitUserStyleSheet