pub struct WebResource { /* private fields */ }Expand description
Represents a resource at the end of a URI.
A WebResource encapsulates content for each resource at the
end of a particular URI. For example, one WebResource will
be created for each separate image and stylesheet when a page is
loaded.
You can access the response and the URI for a given
WebResource, using uri() and
response(), as well as the raw data, using
data().
Properties
response
The URIResponse associated with this resource.
Readable
uri
The current active URI of the WebResource.
See WebResource::uri() for more details.
Readable
Signals
failed
This signal is emitted when an error occurs during the resource load operation.
failed-with-tls-errors
This signal is emitted when a TLS error occurs during the resource load operation.
finished
This signal is emitted when the resource load finishes successfully
or due to an error. In case of errors failed signal
is emitted before this one.
sent-request
This signal is emitted when request has been sent to the
server. In case of a server redirection this signal is
emitted again with the request argument containing the new
request sent to the server due to the redirection and the
redirected_response parameter containing the response
received by the server for the initial request.
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl WebResource
impl WebResource
Sourcepub fn data<P: FnOnce(Result<Vec<u8>, Error>) + 'static>(
&self,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn data<P: FnOnce(Result<Vec<u8>, Error>) + 'static>( &self, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously get the raw data for self.
When the operation is finished, callback will be called. You can then call
webkit_web_resource_get_data_finish() to get the result of the operation.
cancellable
a gio::Cancellable or None to ignore
callback
a GAsyncReadyCallback to call when the request is satisfied
pub fn data_future( &self, ) -> Pin<Box_<dyn Future<Output = Result<Vec<u8>, Error>> + 'static>>
Sourcepub fn response(&self) -> Option<URIResponse>
pub fn response(&self) -> Option<URIResponse>
Retrieves the URIResponse of the resource load operation.
This method returns None if called before the response
is received from the server. You can connect to notify::response
signal to be notified when the response is received.
Returns
the URIResponse, or None if
the response hasn’t been received yet.
Sourcepub fn uri(&self) -> Option<GString>
pub fn uri(&self) -> Option<GString>
Returns the current active URI of self.
The active URI might change during a load operation:
<orderedlist>
<listitem>``<para>
When the resource load starts, the active URI is the requested URI
</para>``</listitem>
<listitem>``<para>
When the initial request is sent to the server, sent-request
signal is emitted without a redirected response, the active URI is the URI of
the request sent to the server.
</para>``</listitem>
<listitem>``<para>
In case of a server redirection, sent-request signal
is emitted again with a redirected response, the active URI is the URI the request
was redirected to.
</para>``</listitem>
<listitem>``<para>
When the response is received from the server, the active URI is the final
one and it will not change again.
</para>``</listitem>
</orderedlist>
You can monitor the active URI by connecting to the notify::uri
signal of self.
Returns
the current active URI of self
Sourcepub fn connect_failed<F: Fn(&Self, &Error) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_failed<F: Fn(&Self, &Error) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when an error occurs during the resource load operation.
error
the glib::Error that was triggered
Sourcepub fn connect_failed_with_tls_errors<F: Fn(&Self, &TlsCertificate, TlsCertificateFlags) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_failed_with_tls_errors<F: Fn(&Self, &TlsCertificate, TlsCertificateFlags) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when a TLS error occurs during the resource load operation.
certificate
errors
a gio::TlsCertificateFlags with the verification status of certificate
Sourcepub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_finished<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
This signal is emitted when the resource load finishes successfully
or due to an error. In case of errors failed signal
is emitted before this one.
Sourcepub fn connect_sent_request<F: Fn(&Self, &URIRequest, &URIResponse) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_sent_request<F: Fn(&Self, &URIRequest, &URIResponse) + 'static>( &self, f: F, ) -> SignalHandlerId
This signal is emitted when request has been sent to the
server. In case of a server redirection this signal is
emitted again with the request argument containing the new
request sent to the server due to the redirection and the
redirected_response parameter containing the response
received by the server for the initial request.
request
redirected_response
a URIResponse, or None
pub fn connect_response_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_uri_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId