pub struct WebsiteData { /* private fields */ }Expand description
Data stored locally by a web site.
WebKitWebsiteData represents data stored in the client by a particular website. A website is normally a set of URLs grouped by domain name. You can get the website name, which is usually the domain, with webkit_website_data_get_name(). Documents loaded from the file system, like file:// URIs, are all grouped in the same WebKitWebsiteData with the name “Local files”.
A website can store different types of data in the client side. #WebKitWebsiteDataTypes is an enum containing all the possible data types; use webkit_website_data_get_types() to get the bitmask of data types. It’s also possible to know the size of the data stored for some of the #WebKitWebsiteDataTypes by using webkit_website_data_get_size().
A list of WebKitWebsiteData can be retrieved with webkit_website_data_manager_fetch(). See #WebKitWebsiteDataManager for more information.
GLib type: Shared boxed type with reference counted clone semantics.
Implementations
Sourceimpl WebsiteData
impl WebsiteData
Sourcepub fn as_ptr(&self) -> *mut WebKitWebsiteData
pub fn as_ptr(&self) -> *mut WebKitWebsiteData
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitWebsiteData) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut WebKitWebsiteData) -> &Self
Borrows the underlying C value.
Sourceimpl WebsiteData
impl WebsiteData
Sourcepub fn name(&self) -> Option<GString>
pub fn name(&self) -> Option<GString>
Gets the name of #WebKitWebsiteData.
This is the website name, normally represented by a domain or host name. All local documents are grouped in the same #WebKitWebsiteData using the name “Local files”.
Returns
the website name of @self.
Sourcepub fn size(&self, types: WebsiteDataTypes) -> u64
pub fn size(&self, types: WebsiteDataTypes) -> u64
Gets the size of the data of types @types in a #WebKitWebsiteData.
Note that currently the data size is only known for WebsiteDataTypes::DISK_CACHE data type
so for all other types 0 will be returned.
types
a bitmask of #WebKitWebsiteDataTypes
Returns
the size of @self for the given @types.
Sourcepub fn types(&self) -> WebsiteDataTypes
pub fn types(&self) -> WebsiteDataTypes
Gets the types of data stored in the client for a #WebKitWebsiteData.
These are the types actually present, not the types queried with webkit_website_data_manager_fetch().
Returns
a bitmask of #WebKitWebsiteDataTypes in @self