pub struct WebsiteDataManager { /* private fields */ }Expand description
Manages data stored locally by web sites.
You can use WebKitWebsiteDataManager to configure the local directories
where website data will be stored. Use base-data-directory
and base-cache-directory set a common base directory for all
website data and caches.
A WebKitWebsiteDataManager can be ephemeral, in which case all the directory configuration
is not needed because website data will never persist. You can create an ephemeral WebKitWebsiteDataManager
with webkit_website_data_manager_new_ephemeral().
WebKitWebsiteDataManager can also be used to fetch website data, remove data stored by particular websites, or clear data for all websites modified since a given period of time.
Properties
base-cache-directory
The base directory for caches. If None, a default location will be used.
Readable | Writeable | Construct Only
base-data-directory
The base directory for website data. If None, a default location will be used.
Readable | Writeable | Construct Only
is-ephemeral
Whether the WebsiteDataManager is ephemeral. An ephemeral WebsiteDataManager
handles all websites data as non-persistent, and nothing will be written to the client
storage. Note that if you create an ephemeral WebsiteDataManager all other construction
parameters to configure data directories will be ignored.
Readable | Writeable | Construct Only
origin-storage-ratio
The percentage of volume space that can be used for data storage for every domain. If the maximum storage is reached the storage request will fail with a QuotaExceededError exception. A value of 0.0 means that data storage is not allowed. A value of -1.0, which is the default, means WebKit will use the default quota (1 GiB).
Writeable | Construct Only
total-storage-ratio
The percentage of volume space that can be used for data storage for all domains. If the maximum storage is reached the eviction will happen. A value of 0.0 means that data storage is not allowed. A value of -1.0, which is the default, means there’s no limit for the total storage.
Writeable | Construct Only
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl WebsiteDataManager
impl WebsiteDataManager
Sourcepub fn clear<P: FnOnce(Result<(), Error>) + Send + 'static>(
&self,
types: WebsiteDataTypes,
timespan: TimeSpan,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn clear<P: FnOnce(Result<(), Error>) + Send + 'static>( &self, types: WebsiteDataTypes, timespan: TimeSpan, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously clear the website data of the given types modified in the past timespan.
If timespan is 0, all website data will be removed.
When the operation is finished, callback will be called. You can then call
webkit_website_data_manager_clear_finish() to get the result of the operation.
Due to implementation limitations, this function does not currently delete
any stored cookies if timespan is nonzero. This behavior may change in the
future.
types
timespan
a GTimeSpan
cancellable
a gio::Cancellable or None to ignore
callback
a GAsyncReadyCallback to call when the request is satisfied
Sourcepub fn remove<P: FnOnce(Result<(), Error>) + Send + 'static>(
&self,
types: WebsiteDataTypes,
website_data: &[&WebsiteData],
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn remove<P: FnOnce(Result<(), Error>) + Send + 'static>( &self, types: WebsiteDataTypes, website_data: &[&WebsiteData], cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously removes the website data in the given website_data list.
Asynchronously removes the website data of the given types for websites in the given website_data list.
Use clear() if you want to remove the website data for all sites.
When the operation is finished, callback will be called. You can then call
webkit_website_data_manager_remove_finish() to get the result of the operation.
types
website_data
a GList of WebsiteData
cancellable
a gio::Cancellable or None to ignore
callback
a GAsyncReadyCallback to call when the request is satisfied
Sourceimpl WebsiteDataManager
impl WebsiteDataManager
Sourcepub fn builder() -> WebsiteDataManagerBuilder
pub fn builder() -> WebsiteDataManagerBuilder
Creates a new builder-pattern struct instance to construct WebsiteDataManager objects.
This method returns an instance of WebsiteDataManagerBuilder which can be used to create WebsiteDataManager objects.
Sourcepub fn fetch<P: FnOnce(Result<Vec<WebsiteData>, Error>) + 'static>(
&self,
types: WebsiteDataTypes,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn fetch<P: FnOnce(Result<Vec<WebsiteData>, Error>) + 'static>( &self, types: WebsiteDataTypes, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously get the list of WebsiteData for the given types.
When the operation is finished, callback will be called. You can then call
webkit_website_data_manager_fetch_finish() to get the result of the operation.
types
cancellable
a gio::Cancellable or None to ignore
callback
a GAsyncReadyCallback to call when the request is satisfied
pub fn fetch_future( &self, types: WebsiteDataTypes, ) -> Pin<Box_<dyn Future<Output = Result<Vec<WebsiteData>, Error>> + 'static>>
Sourcepub fn base_cache_directory(&self) -> Option<GString>
pub fn base_cache_directory(&self) -> Option<GString>
Get the base-cache-directory property.
Returns
the base directory for caches, or None if
base-cache-directory was not provided or self is ephemeral.
Sourcepub fn base_data_directory(&self) -> Option<GString>
pub fn base_data_directory(&self) -> Option<GString>
Get the base-data-directory property.
Returns
the base directory for website data, or None if
base-data-directory was not provided or self is ephemeral.
Sourcepub fn favicon_database(&self) -> Option<FaviconDatabase>
pub fn favicon_database(&self) -> Option<FaviconDatabase>
Sourcepub fn is_favicons_enabled(&self) -> bool
pub fn is_favicons_enabled(&self) -> bool
Sourcepub fn itp_summary<P: FnOnce(Result<Vec<ITPThirdParty>, Error>) + 'static>(
&self,
cancellable: Option<&impl IsA<Cancellable>>,
callback: P,
)
pub fn itp_summary<P: FnOnce(Result<Vec<ITPThirdParty>, Error>) + 'static>( &self, cancellable: Option<&impl IsA<Cancellable>>, callback: P, )
Asynchronously get the list of ITPThirdParty seen for self.
Every ITPThirdParty
contains the list of ITPFirstParty under which it has been seen.
When the operation is finished, callback will be called. You can then call
webkit_website_data_manager_get_itp_summary_finish() to get the result of the operation.
cancellable
a gio::Cancellable or None to ignore
callback
a GAsyncReadyCallback to call when the request is satisfied
pub fn itp_summary_future( &self, ) -> Pin<Box_<dyn Future<Output = Result<Vec<ITPThirdParty>, Error>> + 'static>>
Sourcepub fn is_ephemeral(&self) -> bool
pub fn is_ephemeral(&self) -> bool
Sourcepub fn set_favicons_enabled(&self, enabled: bool)
pub fn set_favicons_enabled(&self, enabled: bool)
Set whether website icons are enabled. Website icons are disabled by default.
When website icons are disabled, the FaviconDatabase of self is closed and
its reference removed, so favicon_database() will
return None. If website icons are enabled again, a new FaviconDatabase will
be created.
enabled
value to set