pub struct WebsiteDataTypes(/* private fields */);Expand description
Enum values with flags representing types of Website data.
Implementations
Sourceimpl WebsiteDataTypes
impl WebsiteDataTypes
Sourcepub const MEMORY_CACHE: Self
pub const MEMORY_CACHE: Self
Memory cache.
Sourcepub const DISK_CACHE: Self
pub const DISK_CACHE: Self
HTTP disk cache.
Sourcepub const OFFLINE_APPLICATION_CACHE: Self
pub const OFFLINE_APPLICATION_CACHE: Self
Offline web application cache.
Sourcepub const SESSION_STORAGE: Self
pub const SESSION_STORAGE: Self
Session storage data.
Sourcepub const LOCAL_STORAGE: Self
pub const LOCAL_STORAGE: Self
Local storage data.
Sourcepub const INDEXEDDB_DATABASES: Self
pub const INDEXEDDB_DATABASES: Self
IndexedDB databases.
Sourcepub const DEVICE_ID_HASH_SALT: Self
pub const DEVICE_ID_HASH_SALT: Self
Hash salt used to generate the device ids used by webpages.
Sourcepub const HSTS_CACHE: Self
pub const HSTS_CACHE: Self
HSTS cache.
Sourcepub const SERVICE_WORKER_REGISTRATIONS: Self
pub const SERVICE_WORKER_REGISTRATIONS: Self
Service worker registrations.
Sourceimpl WebsiteDataTypes
impl WebsiteDataTypes
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WebsiteDataTypes
impl WebsiteDataTypes
Sourcepub const fn iter(&self) -> Iter<WebsiteDataTypes>
pub const fn iter(&self) -> Iter<WebsiteDataTypes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WebsiteDataTypes>
pub const fn iter_names(&self) -> IterNames<WebsiteDataTypes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.