pub struct WindowProperties { /* private fields */ }Expand description
Window properties of a WebView.
The content of a WebView can request to change certain
properties of the window containing the view. This can include the x, y position
of the window, the width and height but also if a toolbar,
scrollbar, statusbar, locationbar should be visible to the user,
and the request to show the WebView fullscreen.
The ready-to-show signal handler is the proper place
to apply the initial window properties. Then you can monitor the
WindowProperties by connecting to ::notify signal.
⚠️ The following code is in c ⚠️
static void ready_to_show_cb (WebKitWebView *web_view, gpointer user_data)
{
GtkWidget *window;
WebKitWindowProperties *window_properties;
gboolean visible;
// Create the window to contain the WebKitWebView.
window = browser_window_new ();
gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET (web_view));
gtk_widget_show (GTK_WIDGET (web_view));
// Get the WebKitWindowProperties of the web view and monitor it.
window_properties = webkit_web_view_get_window_properties (web_view);
g_signal_connect (window_properties, "notify::geometry",
G_CALLBACK (window_geometry_changed), window);
g_signal_connect (window_properties, "notify::toolbar-visible",
G_CALLBACK (window_toolbar_visibility_changed), window);
g_signal_connect (window_properties, "notify::menubar-visible",
G_CALLBACK (window_menubar_visibility_changed), window);
// Apply the window properties before showing the window.
visible = webkit_window_properties_get_toolbar_visible (window_properties);
browser_window_set_toolbar_visible (BROWSER_WINDOW (window), visible);
visible = webkit_window_properties_get_menubar_visible (window_properties);
browser_window_set_menubar_visible (BROWSER_WINDOW (window), visible);
if (webkit_window_properties_get_fullscreen (window_properties)) {
gtk_window_fullscreen (GTK_WINDOW (window));
} else {
GdkRectangle geometry;
gtk_window_set_resizable (GTK_WINDOW (window),
webkit_window_properties_get_resizable (window_properties));
webkit_window_properties_get_geometry (window_properties, &geometry);
gtk_window_move (GTK_WINDOW (window), geometry.x, geometry.y);
gtk_window_resize (GTK_WINDOW (window), geometry.width, geometry.height);
}
gtk_widget_show (window);
}Properties
fullscreen
Whether window will be displayed fullscreen.
Readable | Writeable | Construct Only
geometry
The size and position of the window on the screen.
Readable | Writeable | Construct Only
locationbar-visible
Whether the locationbar should be visible for the window.
Readable | Writeable | Construct Only
menubar-visible
Whether the menubar should be visible for the window.
Readable | Writeable | Construct Only
resizable
Whether the window can be resized.
Readable | Writeable | Construct Only
scrollbars-visible
Whether the scrollbars should be visible for the window.
Readable | Writeable | Construct Only
statusbar-visible
Whether the statusbar should be visible for the window.
Readable | Writeable | Construct Only
toolbar-visible
Whether the toolbar should be visible for the window.
Readable | Writeable | Construct Only
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl WindowProperties
impl WindowProperties
Sourcepub fn builder() -> WindowPropertiesBuilder
pub fn builder() -> WindowPropertiesBuilder
Creates a new builder-pattern struct instance to construct WindowProperties objects.
This method returns an instance of WindowPropertiesBuilder which can be used to create WindowProperties objects.
Sourcepub fn is_fullscreen(&self) -> bool
pub fn is_fullscreen(&self) -> bool
Sourcepub fn is_locationbar_visible(&self) -> bool
pub fn is_locationbar_visible(&self) -> bool
Sourcepub fn is_resizable(&self) -> bool
pub fn is_resizable(&self) -> bool
Sourcepub fn is_scrollbars_visible(&self) -> bool
pub fn is_scrollbars_visible(&self) -> bool
Sourcepub fn is_statusbar_visible(&self) -> bool
pub fn is_statusbar_visible(&self) -> bool