pub struct ContextMenu { /* private fields */ }Expand description
Represents the context menu in a #WebKitWebView.
#WebKitContextMenu represents a context menu containing #WebKitContextMenuItems in a #WebKitWebView.
When a #WebKitWebView is about to display the context menu, it emits the #WebKitWebView::context-menu signal, which has the #WebKitContextMenu as an argument. You can modify it, adding new submenus that you can create with webkit_context_menu_new(), adding new #WebKitContextMenuItems with webkit_context_menu_prepend(), webkit_context_menu_append() or webkit_context_menu_insert(), maybe after having removed the existing ones with webkit_context_menu_remove_all().
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ContextMenu
impl ContextMenu
Sourcepub fn new() -> ContextMenu
pub fn new() -> ContextMenu
Creates a new #WebKitContextMenu object.
Creates a new #WebKitContextMenu object to be used as a submenu of an existing #WebKitContextMenu. The context menu of a #WebKitWebView is created by the view and passed as an argument of #WebKitWebView::context-menu signal. To add items to the menu use webkit_context_menu_prepend(), webkit_context_menu_append() or webkit_context_menu_insert(). See also webkit_context_menu_new_with_items() to create a #WebKitContextMenu with a list of initial items.
Returns
The newly created #WebKitContextMenu object
Sourcepub fn with_items(items: &[ContextMenuItem]) -> ContextMenu
pub fn with_items(items: &[ContextMenuItem]) -> ContextMenu
Creates a new #WebKitContextMenu object with the given items.
Creates a new #WebKitContextMenu object to be used as a submenu of an existing #WebKitContextMenu with the given initial items. See also webkit_context_menu_new()
items
a #GList of #WebKitContextMenuItem
Returns
The newly created #WebKitContextMenu object
Sourcepub fn append(&self, item: &ContextMenuItem)
pub fn append(&self, item: &ContextMenuItem)
Sourcepub fn first(&self) -> Option<ContextMenuItem>
pub fn first(&self) -> Option<ContextMenuItem>
Sourcepub fn event(&self) -> Option<Event>
pub fn event(&self) -> Option<Event>
Gets the #GdkEvent that triggered the context menu. This function only returns a valid
#GdkEvent when called for a #WebKitContextMenu passed to #WebKitWebView::context-menu
signal; in all other cases, None is returned.
The returned #GdkEvent is expected to be one of the following types:
GDK_BUTTON_PRESS when the context menu was triggered with mouse.
GDK_KEY_PRESS if the keyboard was used to show the menu.
GDK_NOTHING when the #GtkWidget::popup-menu signal was used to show the context menu.
Returns
the menu event or None.
Sourcepub fn item_at_position(&self, position: u32) -> Option<ContextMenuItem>
pub fn item_at_position(&self, position: u32) -> Option<ContextMenuItem>
Sourcepub fn items(&self) -> Vec<ContextMenuItem>
pub fn items(&self) -> Vec<ContextMenuItem>
Sourcepub fn insert(&self, item: &ContextMenuItem, position: i32)
pub fn insert(&self, item: &ContextMenuItem, position: i32)
Sourcepub fn last(&self) -> Option<ContextMenuItem>
pub fn last(&self) -> Option<ContextMenuItem>
Sourcepub fn move_item(&self, item: &ContextMenuItem, position: i32)
pub fn move_item(&self, item: &ContextMenuItem, position: i32)
Sourcepub fn prepend(&self, item: &ContextMenuItem)
pub fn prepend(&self, item: &ContextMenuItem)
Sourcepub fn remove(&self, item: &ContextMenuItem)
pub fn remove(&self, item: &ContextMenuItem)
Removes @item from the @self.
See also webkit_context_menu_remove_all() to remove all items.
item
the #WebKitContextMenuItem to remove
Sourcepub fn remove_all(&self)
pub fn remove_all(&self)
Removes all items of the @self.
Sourcepub fn set_user_data(&self, user_data: &Variant)
pub fn set_user_data(&self, user_data: &Variant)
Sets user data to @self.
This function can be used from a Web Process extension to set user data that can be retrieved from the UI Process using webkit_context_menu_get_user_data(). If the @user_data #GVariant is floating, it is consumed.